@@ -7,6 +7,10 @@ import astropy.units as u
 
 from ..i18n import get_translator
 from ..utils import console, display_table, handle_astroquery_exception, global_keyboard_interrupt_handler
+import re # Import re
+from io import StringIO # Import StringIO
+from contextlib import redirect_stdout # Import redirect_stdout
+from astroquery_cli.common_options import setup_debug_context # Import setup_debug_context
 
 def get_app():
     import builtins
@@ -14,9 +18,57 @@ def get_app():
     app = typer.Typer(
         name="vizier",
         help=builtins._("Query the VizieR astronomical catalog service."),
-        no_args_is_help=True
+        invoke_without_command=True, # Add this to allow callback to run without subcommand
+        no_args_is_help=False # Set to False for custom handling
     )
 
+    @app.callback()
+    def vizier_callback(
+        ctx: typer.Context,
+        debug: bool = typer.Option(
+            False,
+            "-t",
+            "--debug",
+            help=_("Enable debug mode with verbose output."),
+            envvar="AQC_DEBUG"
+        ),
+        verbose: bool = typer.Option(
+            False,
+            "-v",
+            "--verbose",
+            help=_("Enable verbose output.")
+        )
+    ):
+        setup_debug_context(ctx, debug, verbose)
+
+        # Custom help display logic
+        if ctx.invoked_subcommand is None and \
+           not any(arg in ["-h", "--help"] for arg in ctx.args): # Use ctx.args for subcommand arguments
+            # Capture the full help output by explicitly calling the app with --help
+            help_output_capture = StringIO()
+            with redirect_stdout(help_output_capture):
+                try:
+                    # Call the app with --help to get the full help output
+                    # Pass the current command's arguments to simulate the help call
+                    app(ctx.args + ["--help"])
+                except SystemExit:
+                    pass # Typer exits after showing help, catch the SystemExit exception
+            full_help_text = help_output_capture.getvalue()
+
+            # Extract only the "Commands" section using regex, including the full bottom border
+            commands_match = re.search(r'╭─ Commands ─.*?(\n(?:│.*?\n)*)╰─.*─╯', full_help_text, re.DOTALL)
+            if commands_match:
+                commands_section = commands_match.group(0)
+                # Remove the "Usage:" line if present in the full help text
+                filtered_commands_section = "\n".join([
+                    line for line in commands_section.splitlines() if "Usage:" not in line
+                ])
+                console.print(filtered_commands_section)
+            else:
+                # Fallback: if commands section not found, print full help
+                console.print(full_help_text)
+            raise typer.Exit()
+
     # ================== VIZIER_FIELDS ===========================
     VIZIER_FIELDS = [
         "HIP",
@@ -170,11 +222,14 @@ def get_app():
         coords = parse_coordinates(ctx, target)
         rad_quantity = parse_angle_str_to_quantity(ctx, radius)
 
-        viz = Vizier(columns=columns if columns else ["*"], catalog=catalogs_to_query, column_filters=column_filters, row_limit=row_limit)
+        # Process column_filters to be a dictionary as expected by Vizier
+        processed_column_filters = parse_constraints_list(ctx, column_filters)
+
+        viz = Vizier(columns=columns if columns else ["*"], catalog=catalogs_to_query, column_filters=processed_column_filters, row_limit=row_limit)
 
         try:
             result_tables = viz.query_object(
-                object_name_or_coordinates=coords,
+                coords,
                 radius=rad_quantity,
             )
 
